Things to read
==============

OAuth 2.0 Authorization Protocol - http://tools.ietf.org/html/draft-ietf-oauth-v2

OAuth 2.0 Bearer Tokens - http://tools.ietf.org/html/draft-ietf-oauth-v2-bearer


All different flavors:

* Yandex - http://api.yandex.ru/oauth/doc/dg/concepts/About.xml
* GitHub - http://developer.github.com/v3/oauth/
* Google - http://code.google.com/intl/en/apis/accounts/docs/OAuth2.html
* Facebook - http://developers.facebook.com/docs/authentication/